@@ -87,12 +87,26 @@ GROUP_DECLARE(Fl_Color_Chooser)
 
 WIDGET_DECLARE(Fl_Flex)
 
-void Fl_Flex_set_size(Fl_Flex *self, Fl_Widget* w, int size);
+void Fl_Flex_set_size(Fl_Flex *self, Fl_Widget *w, int size);
 
-void Fl_Flex_set_debug(Fl_Flex *self, int val);
+void Fl_Flex_set_debug(int val);
+
+void Fl_Flex_set_margin(Fl_Flex *self, int m);
+
+int Fl_Flex_margin(const Fl_Flex *self);
+
+void Fl_Flex_set_pad(Fl_Flex *self, int p);
+
+int Fl_Flex_pad(const Fl_Flex *self);
 
 GROUP_DECLARE(Fl_Flex)
 
+WIDGET_DECLARE(Fl_Flow)
+
+void Fl_Flow_rule(Fl_Flow *self, Fl_Widget *wid, const char *inst);
+
+GROUP_DECLARE(Fl_Flow)
+
 #ifdef __cplusplus
 }
 #endif
