@@ -25,6 +25,10 @@ extern "C" {
 
 IMAGE_DECLARE(Fl_Image)
 
+void Fl_Image_set_scaling_algorithm(int algorithm);
+
+int Fl_Image_scaling_algorithm(void);
+
 IMAGE_DECLARE(Fl_JPEG_Image)
 
 Fl_JPEG_Image *Fl_JPEG_Image_new(const char *filename);
@@ -83,6 +87,8 @@ Fl_RGB_Image *Fl_RGB_Image_new(const unsigned char *bits, int W, int H, int dept
 
 Fl_RGB_Image *Fl_RGB_Image_from_data(const unsigned char *bits, int W, int H, int depth, int ld);
 
+Fl_RGB_Image *Fl_RGB_Image_from_pixmap(const Fl_Pixmap *image);
+
 IMAGE_DECLARE(Fl_Shared_Image)
 
 Fl_Shared_Image *Fl_Shared_Image_get(const char *name, int W, int H);
