@@ -547,7 +547,7 @@ void Fl_delete_offscreen(void *bitmap) {
     fl_delete_offscreen((Fl_Offscreen)bitmap);
 }
 
-void Fl_rescale_offscreen(void *ctx) {
+void Fl_rescale_offscreen(void **ctx) {
     fl_open_display();
     fl_rescale_offscreen(*(Fl_Offscreen *)ctx);
 }
